bayespy.inference.vmp.nodes.gamma.GammaDistribution.compute_fixed_moments_and_f
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaDistribution.compute_fixed_moments_and_f